MethodCode class

@author Longzj

@since 2024/11/20 13:43

该类定义了一系列方法码,用于标识不同的操作或消息类型

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accountExtension → const int
accountExtensionCheck → const int
active → const int
authorityError → const int
authoritySuccess → const int
checkPwd → const int
creditDeviceCheckErr → const int
creditDeviceCheckSuccess → const int
creditDeviceErr → const int
creditDeviceSuccess → const int
deviceBind → const int
deviceBindCheck → const int
deviceList → const int
disposal → const int
faceMatch → const int
goldBankDelayResult → const int
gwStatus → const int
managementDataErr → const int
modifyPwd → const int
needCaptcha → const int
needCheckPwd → const int
needCreditDeviceCheck → const int
needGoldBankDelay → const int
offline → const int
proxyApi → const int
pushMessage → const int
pushMessageOffline → const int
resGroup → const int
resource → const int
scanQrcode → const int
slideShow → const int
slideShowErr → const int