SdpResult class

@author Longzj

@since 2025/8/11 17:03

SDP结果 封装了SDP返回的code和data code为结果码,data为结果数据

Available extensions

Constructors

SdpResult({required int code, dynamic data})
SdpResult.fromJson(Map json)
factory

Properties

code int
final
connectedCode bool

Available on SdpResult, provided by the SdpResultExt extension

是否是连接成功状态码,成功的组合见_successCodes
no setter
data → dynamic
final
disconnectCode bool

Available on SdpResult, provided by the SdpResultExt extension

是否是连接失败状态码
no setter
hashCode int
The hash code for this object.
no setterinherited
isPushOffline bool

Available on SdpResult, provided by the SdpResultExt extension

是否是SDK通知会话失效,状态离线
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited