RltCode class
该类定义了一系列结果码,用于标识不同的操作结果
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- accessError → const int
- accessResultError → const int
- approveAppealApplyError → const int
- approveAppealApplySuccess → const int
- authErrCode → const int
- authReadTimeOutException → const int
- authSuccessVpnIsUse → const int
- authTimeOutCode → const int
- bjdxxcodeError → const int
- bjdxxcodeSuccess → const int
- bjdxxgzzsError → const int
- bjdxxgzzsSuccess → const int
- captchaTimeOutCode → const int
- connectServerError → const int
- conNetworkSuccess → const int
- controllerDisconnect → const int
- createVpnSuccess → const int
- disconnect → const int
- disconnectServerError → const int
- errorCode → const int
- faceMatchError → const int
- faceMatchSuccess → const int
- featureConfigSuccess → const int
- forgetPwdAuthError → const int
- forgetPwdAuthSuccess → const int
- forgetPwdEditError → const int
- forgetPwdEditSuccess → const int
- gbApproveAppealError → const int
- gbApproveAppealSuccess → const int
- gbQueryAppealListError → const int
- gbQueryAppealListSuccess → const int
- goldBankDelayError → const int
- goldBankDelayRlt → const int
- goldBankDelaySuccess → const int
- loginAuthTimeOutCode → const int
- needSecondAuth → const int
- queryAppealApplyListError → const int
- queryAppealApplyListSuccess → const int
- refreshAuthError → const int
- refreshCenterStatus → const int
- requestCodeError → const int
- requestCodeSuccess → const int
- scanQrcodeError → const int
- sessionAuthErr → const int
- sessionAuthSuccess → const int
- success → const int
- vpnConnectReset → const int