MethodChannelVpnSdp class
An implementation of VpnSdpPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- VpnSdpPlatform
- MethodChannelVpnSdp
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messageStream
→ Stream<
SdpResult> -
监听消息,返回
SdpResult,其中code和data字段如下:no setteroverride - methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- msgDataChannel → EventChannel
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disconnect(
) → Future< void> -
断开vpn连接,之后messageStream会接收到RltCode.disconnect消息
override
-
isVpnConnected(
) → Future< bool?> -
判断vpn是否已连接
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
proxyApiV2(
{required String host, required int port, required String reqUrl, String method = 'POST', String header = '', int reqType = 1, dynamic body}) → Future -
接口透传,返回透传结果
override
-
reconnect(
) → Future< void> -
vpn重连
override
-
setUp(
{String sn = "", String vpnLocalizedDesc = "", String mac = "", String providerBundleId = ""}) → Future< void> -
初始化参数
override
-
toString(
) → String -
A string representation of this object.
inherited
-
verifyV2(
{required String host, required int port, required String userName, required String password, String authType = '', String jsonStr = '', String captcha = '', String code = '', String func = ''}) → Future -
VPN登录-本地认证
override
-
verifyV3(
{required String host, required int port, required String username, required String reqUrl, String method = 'POST', String header = '', int reqType = 1, dynamic body, String func = ''}) → Future< void> -
VPN登录-三方认证
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited