- Inheritance
-
- Object
- PlatformInterface
- VpnSdpPlatform
- Implementers
Methods
-
disconnect()
→ Future<void>
-
断开vpn连接,之后messageStream会接收到RltCode.disconnect消息
-
isVpnConnected()
→ Future<bool?>
-
判断vpn是否已连接
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
proxyApiV2({required String host, required int port, required String reqUrl, String method = 'POST', int reqType = 2, dynamic body = ""})
→ Future
-
接口透传,返回透传结果
-
reconnect()
→ Future
-
vpn重连
-
setUp({String sn = "", String vpnLocalizedDesc = "", String mac = "", String providerBundleId = ""})
→ Future<void>
-
初始化参数
-
toString()
→ String
-
A string representation of this object.
inherited
-
verifyV2({required String host, required int port, required String userName, required String password, String authType = '', String jsonStr = '', String captcha = '', String code = '', String func = ''})
→ Future<void>
-
VPN登录-本地认证
-
verifyV3({required String host, required int port, required String username, required String reqUrl, String method = 'POST', int reqType = 2, dynamic body = "", String func = ''})
→ Future
-
VPN登录-三方认证